Struct google_analytics3::AccountChildLink
[−]
[src]
pub struct AccountChildLink {
pub href: Option<String>,
pub type_: Option<String>,
}Child link for an account entry. Points to the list of web properties for this account.
This type is not used in any activity, and only used as part of another schema.
Fields
href: Option<String>
Link to the list of web properties for this account.
type_: Option<String>
Type of the child link. Its value is "analytics#webproperties".