Struct google_analytics3::AccountPermissions
[−]
[src]
pub struct AccountPermissions {
pub effective: Option<Vec<String>>,
}Permissions the user has for this account.
This type is not used in any activity, and only used as part of another schema.
Fields
effective: Option<Vec<String>>
All the permissions that the user has for this account. These include any implied permissions (e.g., EDIT implies VIEW).