Struct google_analytics3::AccountTicket [−][src]
pub struct AccountTicket {
pub profile: Option<Profile>,
pub account: Option<Account>,
pub id: Option<String>,
pub webproperty: Option<Webproperty>,
pub kind: Option<String>,
pub redirect_uri: Option<String>,
}JSON template for an Analytics account ticket. The account ticket consists of the ticket ID and the basic information for the account, property and profile.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- create account ticket provisioning (request|response)
Fields
profile: Option<Profile>
View (Profile) for the account.
account: Option<Account>
Account for this ticket.
id: Option<String>
Account ticket ID used to access the account ticket.
webproperty: Option<Webproperty>
Web property for the account.
kind: Option<String>
Resource type for account ticket.
redirect_uri: Option<String>
Redirect URI where the user will be sent after accepting Terms of Service. Must be configured in APIs console as a callback URL.