Struct google_analytics3::Column [−][src]
pub struct Column {
pub attributes: Option<HashMap<String, String>>,
pub kind: Option<String>,
pub id: Option<String>,
}JSON template for a metadata column.
This type is not used in any activity, and only used as part of another schema.
Fields
attributes: Option<HashMap<String, String>>
Map of attribute name and value for this column.
kind: Option<String>
Resource type for Analytics column.
id: Option<String>
Column id.