Struct google_analytics3::CustomDataSourceChildLink [−][src]
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
href: Option<String>
Link to the list of daily uploads for this custom data source. Link to the list of uploads for this custom data source.
type_: Option<String>
Value is "analytics#dailyUploads". Value is "analytics#uploads".