Struct google_analytics3::CustomDataSourceParentLink [−][src]
Parent link for this custom data source. Points to the web property to which this custom data source belongs.
This type is not used in any activity, and only used as part of another schema.
Fields
href: Option<String>
Link to the web property to which this custom data source belongs.
type_: Option<String>
Value is "analytics#webproperty".