Struct google_analytics3::CustomDimensionParentLink [−][src]
Parent link for the custom dimension. Points to the property to which the custom dimension belongs.
This type is not used in any activity, and only used as part of another schema.
Fields
href: Option<String>
Link to the property to which the custom dimension belongs.
type_: Option<String>
Type of the parent link. Set to "analytics#webproperty".