Struct google_analytics3::EntityUserLinkEntity [−][src]
pub struct EntityUserLinkEntity {
pub account_ref: Option<AccountRef>,
pub profile_ref: Option<ProfileRef>,
pub web_property_ref: Option<WebPropertyRef>,
}Entity for this link. It can be an account, a web property, or a view (profile).
This type is not used in any activity, and only used as part of another schema.
Fields
account_ref: Option<AccountRef>
Account for this link.
profile_ref: Option<ProfileRef>
View (Profile) for this link.
web_property_ref: Option<WebPropertyRef>
Web property for this link.