Struct google_analytics3::Webproperty [−][src]
pub struct Webproperty {
pub updated: Option<String>,
pub data_retention_ttl: Option<String>,
pub default_profile_id: Option<String>,
pub profile_count: Option<i32>,
pub internal_web_property_id: Option<String>,
pub child_link: Option<WebpropertyChildLink>,
pub industry_vertical: Option<String>,
pub parent_link: Option<WebpropertyParentLink>,
pub account_id: Option<String>,
pub kind: Option<String>,
pub name: Option<String>,
pub created: Option<String>,
pub level: Option<String>,
pub id: Option<String>,
pub website_url: Option<String>,
pub data_retention_reset_on_new_activity: Option<bool>,
pub starred: Option<bool>,
pub permissions: Option<WebpropertyPermissions>,
pub self_link: Option<String>,
}JSON template for an Analytics web property.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- webproperties insert management (request|response)
- webproperties update management (request|response)
- webproperties get management (response)
- webproperties patch management (request|response)
Fields
updated: Option<String>
Time this web property was last modified.
data_retention_ttl: Option<String>
The length of time for which user and event data is retained. This property cannot be set on insert.
default_profile_id: Option<String>
Default view (profile) ID.
profile_count: Option<i32>
View (Profile) count for this web property.
internal_web_property_id: Option<String>
Internal ID for this web property.
child_link: Option<WebpropertyChildLink>
Child link for this web property. Points to the list of views (profiles) for this web property.
industry_vertical: Option<String>
The industry vertical/category selected for this web property.
parent_link: Option<WebpropertyParentLink>
Parent link for this web property. Points to the account to which this web property belongs.
account_id: Option<String>
Account ID to which this web property belongs.
kind: Option<String>
Resource type for Analytics WebProperty.
name: Option<String>
Name of this web property.
created: Option<String>
Time this web property was created.
level: Option<String>
Level for this web property. Possible values are STANDARD or PREMIUM.
id: Option<String>
Web property ID of the form UA-XXXXX-YY.
website_url: Option<String>
Website url for this web property.
data_retention_reset_on_new_activity: Option<bool>
Set to true to reset the retention period of the user identifier with each new event from that user (thus setting the expiration date to current time plus retention period). Set to false to delete data associated with the user identifer automatically after the rentention period. This property cannot be set on insert.
starred: Option<bool>
Indicates whether this web property is starred or not.
permissions: Option<WebpropertyPermissions>
Permissions the user has for this web property.
self_link: Option<String>
Link for this web property.