Struct google_analytics3::AccountTreeResponse [−][src]
pub struct AccountTreeResponse {
pub profile: Option<Profile>,
pub account_settings: Option<AccountTreeResponseAccountSettings>,
pub account: Option<Account>,
pub webproperty: Option<Webproperty>,
pub kind: Option<String>,
}JSON template for an Analytics account tree response. The account tree response is used in the provisioning api to return the result of creating an account, property, and view (profile).
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- create account tree provisioning (response)
Fields
profile: Option<Profile>
View (Profile) for the account.
account_settings: Option<AccountTreeResponseAccountSettings>
no description provided
account: Option<Account>
The account created.
webproperty: Option<Webproperty>
Web property for the account.
kind: Option<String>
Resource type for account ticket.